Save the state in javascript tree

# Example 4 - Save the state

If you set the option saveState to true, then jqtree remembers the tree state after a page reload.

- JqTree save the state into localStorage. If the browser does not support localStorage, then jqTree saves the state in a cookie.
- You must include the jquery-cookie plugin for cookie support.

### html

    <div id="tree1" data-url="/example_data/"></div>

### javascript

    $('#tree1').tree({
        saveState: true
    });

Giving the saveState a string value sets the storage key. The default key is 'tree'.

    $('#tree1').tree({
        saveState: 'my-tree'
    });